"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProviderService = void 0;
const aws_xray_sdk_core_1 = __importDefault(require("aws-xray-sdk-core"));
const { captureAWS, captureAWSClient, captureAWSv3Client, captureAsyncFunc, captureFunc, captureHTTPsGlobal, getNamespace, getSegment, setSegment, Segment: XraySegment, setContextMissingStrategy, setDaemonAddress, setLogger, } = aws_xray_sdk_core_1.default;
const commons_1 = require("@aws-lambda-powertools/commons");
class ProviderService {
    captureAWS(awssdk) {
        return captureAWS(awssdk);
    }
    captureAWSClient(service) {
        return captureAWSClient(service);
    }
    captureAWSv3Client(service) {
        (0, commons_1.addUserAgentMiddleware)(service, 'tracer');
        // Type must be aliased as any because of this https://github.com/aws/aws-xray-sdk-node/issues/439#issuecomment-859715660
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        return captureAWSv3Client(service);
    }
    captureAsyncFunc(name, fcn, _parent) {
        return captureAsyncFunc(name, fcn);
    }
    captureFunc(name, fcn, _parent) {
        return captureFunc(name, fcn);
    }
    captureHTTPsGlobal() {
        // eslint-disable-next-line @typescript-eslint/no-var-requires
        captureHTTPsGlobal(require('http'));
        // eslint-disable-next-line @typescript-eslint/no-var-requires
        captureHTTPsGlobal(require('https'));
    }
    getNamespace() {
        return getNamespace();
    }
    getSegment() {
        return getSegment();
    }
    putAnnotation(key, value) {
        const segment = this.getSegment();
        if (segment === undefined) {
            console.warn('No active segment or subsegment found, skipping annotation');
            return;
        }
        if (segment instanceof XraySegment) {
            console.warn('You cannot annotate the main segment in a Lambda execution environment');
            return;
        }
        segment.addAnnotation(key, value);
    }
    putMetadata(key, value, namespace) {
        const segment = this.getSegment();
        if (segment === undefined) {
            console.warn('No active segment or subsegment found, skipping metadata addition');
            return;
        }
        if (segment instanceof XraySegment) {
            console.warn('You cannot add metadata to the main segment in a Lambda execution environment');
            return;
        }
        segment.addMetadata(key, value, namespace);
    }
    setContextMissingStrategy(strategy) {
        setContextMissingStrategy(strategy);
    }
    setDaemonAddress(address) {
        setDaemonAddress(address);
    }
    setLogger(logObj) {
        setLogger(logObj);
    }
    setSegment(segment) {
        setSegment(segment);
    }
}
exports.ProviderService = ProviderService;
